@@ -59,8 +59,11 @@ class PraatLoader:
         com = [self.praat, os.path.join(self.script_dir,name)] + map(str,args)
         if self.debug:
             self.updatelog('%s' % str(com))
+        orig = os.getuid()
+        os.setuid(1000)
         p = subprocess.Popen(com,stdout=subprocess.PIPE,stderr=subprocess.PIPE,stdin=subprocess.PIPE)
         stdout, stderr = p.communicate()
+        os.setuid(orig)
         if self.debug:
             self.updatelog('stdout: %s' % str(stdout))
             self.updatelog('stderr: %s' % str(stderr))
